@@ -4,9 +4,11 @@ from nandboxbots.outmessages.OutMessage import OutMessage
 
 
 class DeleteBlackListPatternsOutMessage(OutMessage):
-    __KEY_PATTERN = "pattern"
+    __KEY_PATTERN = "patterns"
 
     pattern = []
+    def __init__(self):
+        self.method = "removeBlacklistPatterns"
 
     def to_json_obj(self):
         _, dictionary = super(DeleteBlackListPatternsOutMessage, self).to_json_obj()
