@@ -4,11 +4,12 @@ from nandboxbots.outmessages.OutMessage import OutMessage
 
 
 class GetChatMemberOutMessage(OutMessage):
+    __KEY_CHAT_ID  = "chat_id"
     __KEY_USER_ID = "user_id"
-
     user_id = None
 
     def __init__(self):
+        super()
         self.method = "getChatMember"
 
     def to_json_obj(self):
